use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007003
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Alexander
Aristotle
Bluhm
Dagfinn
Duin
Etheridge
Florian
Ilmari
Inc
Karen
Leon
Mannsåker
Mash
Matthijs
Name
Pagaltzis
Ragwitz
Reini
Sub
Timmermans
Urban
alexander
and
cPanel
ether
fawaka
gfuji
gfx
ilmari
irc
jmash
lib
pagaltzis
rafl
rurban
van
xmath
